package com.chelvc.cloud.maintain.controller;

import java.util.List;
import javax.validation.Valid;

import com.chelvc.cloud.maintain.copier.CommentCopier;
import com.chelvc.cloud.maintain.vo.CommentVO;
import com.chelvc.cloud.vehicle.client.CommentClient;
import com.chelvc.cloud.vehicle.client.dto.CommentDTO;
import com.chelvc.cloud.vehicle.client.param.AddGoodsCommentParam;
import com.chelvc.cloud.vehicle.client.param.CommentQueryParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.base.context.SessionContextHolder;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * 商品评价接口
 *
 * @author Woody
 * @date 2023/8/7
 */
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class CommentController {
    private final CommentClient commentClient;

    /**
     * 获取商品评价列表
     *
     * @param goodsId    商品ID
     * @param parentId   父级评论id
     * @param merchantId 商户id
     * @param param      查询参数
     * @return 商品评价列表
     */
    @GetMapping("/goods/{goodsId}/comments")
    public List<CommentVO> listGoodsComments(
            @PathVariable("goodsId") Long goodsId,
            @PathVariable("parentId") Long parentId,
            @PathVariable("merchantId") Long merchantId,
            @Valid CommentQueryParam param) {
        List<CommentDTO> comments = this.commentClient.listGoodsComments(goodsId, parentId, merchantId, param);
        return CommentCopier.INSTANCE.copying(comments);
    }

    /**
     * 新增商品评价
     *
     * @param param 新增参数
     */
    @PostMapping("/goods/comments/add")
    public void addGoodsComments(@Validated @RequestBody AddGoodsCommentParam param) {
        this.commentClient.addGoodsComments(param, SessionContextHolder.getId());
    }
}
