package com.chelvc.cloud.maintain.controller;

import java.io.IOException;
import java.io.InputStream;

import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.base.util.HttpUtils;
import com.chelvc.framework.common.model.File;
import com.chelvc.framework.common.model.Media;
import com.chelvc.framework.upload.UploadHandler;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

/**
 * 文件接口
 *
 * @author Woody
 * @date 2023/5/4
 */
@Slf4j
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class FileController {
    private final UploadHandler uploadHandler;

    /**
     * 上传文件
     *
     * @param file 文件对象
     * @return 文件地址
     * @throws IOException I/O异常
     */
    @PostMapping("/file")
    public File upload(@RequestParam("file") MultipartFile file) throws IOException {
        Media media = HttpUtils.getMedia(file);
        String filename = HttpUtils.generateUploadFilename(file);
        try (InputStream stream = file.getInputStream()) {
            String url = this.uploadHandler.upload(stream, filename);
            return File.builder().name(filename).media(media).url(url).build();
        }
    }
}
