package com.chelvc.cloud.maintain.controller;

import javax.validation.Valid;

import com.chelvc.cloud.maintain.copier.UserCopier;
import com.chelvc.cloud.maintain.vo.PersonalVO;
import com.chelvc.cloud.user.client.UserClient;
import com.chelvc.cloud.user.client.param.PersonalModifyParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * 用户接口
 *
 * @author Woody
 * @date 2023/4/30
 */
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class UserController {
    private final UserClient userClient;

    /**
     * 获取用户个人信息
     *
     * @return 用户个人信息
     */
    @GetMapping("/user/mine")
    public PersonalVO getPersonal() {
        return UserCopier.INSTANCE.copying(this.userClient.getPersonal());
    }

    /**
     * 修改用户个人信息
     *
     * @param param 修改参数
     */
    @PutMapping("/user/mine")
    public void updatePersonal(@RequestBody @Valid PersonalModifyParam param) {
        this.userClient.updatePersonal(param);
    }
}
